@@ -236,6 +236,18 @@ class CallbackAction(BaseAction):
 
         if "id" not in mapped:
             raise ValueError("id is required in mapped data")
+
+        transaction_detail = mapped.get('payment_transaction_detail', '')
+        redirect_detail = mapped.get('payment_redirect_detail', '')
+
+        if isinstance(transaction_detail, dict):
+            mapped['payment_transaction_detail'] = json.dumps(
+                transaction_detail, ensure_ascii=False, indent=4)
+
+        if isinstance(redirect_detail, dict):
+            mapped['payment_redirect_detail'] = json.dumps(
+                redirect_detail, ensure_ascii=False, indent=4)
+
         try:
             order = self.order_class.objects.get(id=mapped["id"])
             del mapped["id"]
