@@ -21,7 +21,10 @@ class Invoice(models.Model):
 
     category = models.CharField(max_length=10, choices=CATEGORY, default="B2C")
     order = models.ForeignKey(
-        api_settings.ORDER_CLASS, null=True, on_delete=models.CASCADE
+        api_settings.ORDER_CLASS, null=True, blank=True, on_delete=models.CASCADE
+    )
+    monthly_order = models.ForeignKey(
+        api_settings.MONTHLY_ORDER_CLASS, null=True, blank=True, on_delete=models.CASCADE
     )
     amount = models.IntegerField(default=0)
     invoice_type = models.CharField(
