@@ -68,7 +68,7 @@ class EcpayPayment(BasePayment):
                 cart=self.cart,
                 order_id=self.order_id,
                 order_type=self.order_type,
-                payment_type=self.payment_type,
+                payment_type="ecpay",
                 payment_subtype=self.payment_subtype,
             )
             return {
