@@ -11,6 +11,7 @@ DEFAULTS = {
     "LOGISTIC_SENDER_NAME": "",
     "LOGISTIC_SENDER_PHONE": "",
     "LOGISTIC_SENDER_CELLPHONE": "",
+    "MONTHLY_ORDER_CLASS": "",
     "ORDER_CLASS": "revpayment.models.Order",
     "ITEM_CLASS": "revpayment.items.Item",
     "CALC_CLASS": "revpayment.calculations.Calculations",
@@ -31,6 +32,7 @@ DEFAULTS = {
 # List of settings that may be in string import notation.
 IMPORT_STRINGS = [
     "ORDER_CLASS",
+    "MONTHLY_ORDER_CLASS",
     "ITEM_CLASS",
     "CALC_CLASS",
     "CONFIG_CLASS",
